==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-02 17:41+0000\nLast-Translator: Aleksey Kovalev <alexey.kovaliov@gmail.com>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Все предложения"

, "Default Lead List"
: "Список предложений по умолчанию"

, "The default list for new leads"
: "Список предложений для создания новых задач по умолчанию"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Избранный по умолчанию"

, "The default favorite which is loaded on crm startup"
: "Будет загружено по-умолчанию при загрузке CRM"

, "New Lead"
: "Новое предложение"

, "Tags"
: "Теги"

, "Lead name"
: "Название предложения"

, "Responsible"
: "Ответственный"

, "Partner"
: "Партнёр"

, "Customer"
: "Клиент"

, "Leadstate"
: "Состояние предложения"

, "Leadtype"
: "Тип предложения"

, "Leadsource"
: "Источник предложения"

, "Probability"
: "Вероятность"

, "Turnover"
: "Оборот"

, "Estimated end"
: "Предполагаемый конец"

, "Probable Turnover"
: "Возможный оборот"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Контакт"

, "CRM Role"
: "CRM роль"

, "Tasks"
: "Задания"

, "No Tasks to display"
: "Задания отсутствуют"

, "Summary"
: "Описание"

, "Add a task..."
: "Добавить задание..."

, "Due Date"
: "До даты"

, "Priority"
: "Приоритет"

, "Percent"
: "Процент"

, "Status"
: "Статус"

, "Organizer"
: "Организатор"

, "Add new {0}"
: "Добавить новый {0}"

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "Изменить {0}"

, "Edit selected {0}"
: "Изменить выделенные {0}"

, "Please choose the Lead to add the contacts to"
: "Пожалуйста, выберите предложение для добавления контактов"

, "Please select the attenders' role"
: "Пожалуйста, выберите роль участника"

, "Lead, Leads"
: [
  "Предложения"
 ,"Предложения"
 ,"Предложения"
 ,"Предложения"

]
, "Select Lead"
: "Выберите предложение"

, "Role"
: "Роль"

, "Select Role"
: "Выберите роль"

, "Adding {0} contacts to lead"
: "Добавлено {0} контактов в предложение"

, "Phone"
: "Телефон"

, "Mobile"
: "Мобильный"

, "Fax"
: "Факс"

, "E-Mail"
: "Электронная почта"

, "Web"
: "Интернет"

, "Street"
: "Улица"

, "Postalcode"
: "Почтовый индекс"

, "City"
: "Город"

, "Start"
: "Начать"

, "Change type to Customer"
: "Поменять тип на клиента"

, "Change type to Responsible"
: "Поменять тип на ответственного"

, "Change type to Partner"
: "Поменять тип на партнера"

, "Change contact type"
: "Поменять тип контакта"

, "Search for Contacts to add ..."
: "Поиск контактов для добавления..."

, "Name"
: "Имя"

, "Address"
: "Адрес"

, "Data"
: "Данные"

, "Cellphone"
: "Сотовый телефон"

, "End"
: "Конец"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "Продукты"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "Ожидаемый оборот"

, "Description"
: "Описание"

, "Enter description"
: "Введите описание"

, "lead list, lead lists"
: [
  "Лист предложений"
 ,"Лист предложений"
 ,"Листы предложений"
 ,"Листы предложений"

]
, "lead lists"
: "Лист предложений"

, "Quick Search"
: "Быстрый поиск"

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение:"

, "Creation Time"
: "Время создания"

, "Created By"
: "Создано"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Продукт"

, "Price"
: "Цена"

, "Quantity"
: "Количество"

, "Search for Products to add ..."
: "Выбрать продукт, который нужно добавить..."

, "All leads I have read grants for"
: "Все предложения, которые я могу видеть"

, "Last modified by me"
: "Мои последнии изменения"

, "All leads that I have last modified"
: "Все последние изменённые мной предложения"

, "My leads"
: "Мои предложения"

, "All leads that I am responsible for"
: "Все предложения, за которые я ответственнен"

, "Leads with overdue tasks"
: "Предложения с просроченными задачами"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "открытый"

, "contacted"
: "связавшийся"

, "waiting for feedback"
: "ожидающий ответа"

, "quote sent"
: "цена отправлена"

, "accepted"
: "принятый"

, "lost"
: "потерянный"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Реселлер"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Состояние"

, "Source"
: "Источник"

, "Scheduled end"
: "Запланированный конец"

, "Folder"
: "Папка"

, "Updated by"
: "Обновлено"

, "Updated Fields:"
: "Обновлённые поля:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Предложение %s было изменено"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Ведущим %s было создано"

, "Task"
: "Задача"

, "Lead Data"
: "Данные предложения"

, "End Scheduled"
: "Конец запланирован"

, "Contacts"
: "Контакты"

, "Telephone"
: "Телефон"

, "Email"
: "Электронная почта"

, "low"
: "низкий"

, "normal"
: "нормальный"

, "high"
: "высокий"

, "urgent"
: "срочный"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "управлять общими папками предложений"

, "Create new shared lead folders"
: "Создать новую общую папку предложений"

, "manage shared leads favorites"
: "управление избранными общими предложениями"

, "Create or update shared leads favorites"
: "Создание или обновление избранных общих предложений"




, "Lead"
: "Предложения"

, "lead list"
: "Лист предложений"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Клиент"

, "Partner"
: "Партнёр"

, "Phone"
: "Телефон"

, "Mobile"
: "Мобильный"

, "Fax"
: "Факс"

, "E-Mail"
: "Электронная почта"

, "Web"
: "Интернет"

, "Street"
: "Улица"

, "Postalcode"
: "Почтовый индекс"

, "City"
: "Город"

, "Status"
: "Статус"

, "Start"
: "Начать"

, "Estimated end"
: "Предполагаемый конец"

, "Leadtype"
: "Тип предложения"

, "Leadsource"
: "Источник предложения"

, "Tags"
: "Теги"

, "Lead name"
: "Название предложения"

, "Responsible"
: "Ответственный"

, "Leadstate"
: "Состояние предложения"

, "Probability"
: "Вероятность"

, "Turnover"
: "Оборот"

, "End"
: "Конец"

, "Probable Turnover"
: "Возможный оборот"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Добавить новый {0}"

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "Изменить {0}"

, "Edit selected {0}"
: "Изменить выделенные {0}"

, "New Lead"
: "Новое предложение"

, "Products"
: "Продукты"

, "Product"
: "Продукт"

, "Description"
: "Описание"

, "Price"
: "Цена"

, "Quantity"
: "Количество"

, "Search for Products to add ..."
: "Выбрать продукт, который нужно добавить..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Задания"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Lead, Leads"
: [
  "Предложения"
 ,"Предложения"
 ,"Предложения"
 ,"Предложения"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Ожидаемый оборот"

, "Enter description"
: "Введите описание"

, "lead list, lead lists"
: [
  "Лист предложений"
 ,"Лист предложений"
 ,"Листы предложений"
 ,"Листы предложений"

]
, "lead lists"
: "Лист предложений"

, "Quick Search"
: "Быстрый поиск"

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение:"

, "Creation Time"
: "Время создания"

, "Created By"
: "Создано"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Контакт"

, "CRM Role"
: "CRM роль"

, "Change type to Customer"
: "Поменять тип на клиента"

, "Change type to Responsible"
: "Поменять тип на ответственного"

, "Change type to Partner"
: "Поменять тип на партнера"

, "Change contact type"
: "Поменять тип контакта"

, "Search for Contacts to add ..."
: "Поиск контактов для добавления..."

, "Name"
: "Имя"

, "Address"
: "Адрес"

, "Data"
: "Данные"

, "Cellphone"
: "Сотовый телефон"

, "Role"
: "Роль"

, "Please choose the Lead to add the contacts to"
: "Пожалуйста, выберите предложение для добавления контактов"

, "Please select the attenders' role"
: "Пожалуйста, выберите роль участника"

, "Select Lead"
: "Выберите предложение"

, "Select Role"
: "Выберите роль"

, "Adding {0} contacts to lead"
: "Добавлено {0} контактов в предложение"

, "No Tasks to display"
: "Задания отсутствуют"

, "Summary"
: "Описание"

, "Add a task..."
: "Добавить задание..."

, "Due Date"
: "До даты"

, "Priority"
: "Приоритет"

, "Percent"
: "Процент"

, "Organizer"
: "Организатор"

, "All leads"
: "Все предложения"

, "Default Lead List"
: "Список предложений по умолчанию"

, "The default list for new leads"
: "Список предложений для создания новых задач по умолчанию"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Избранный по умолчанию"

, "The default favorite which is loaded on crm startup"
: "Будет загружено по-умолчанию при загрузке CRM"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "открытый"

, "contacted"
: "связавшийся"

, "waiting for feedback"
: "ожидающий ответа"

, "quote sent"
: "цена отправлена"

, "accepted"
: "принятый"

, "lost"
: "потерянный"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Реселлер"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Данные предложения"

, "End Scheduled"
: "Конец запланирован"

, "Contacts"
: "Контакты"

, "Telephone"
: "Телефон"

, "Email"
: "Электронная почта"

, "low"
: "низкий"

, "normal"
: "нормальный"

, "high"
: "высокий"

, "urgent"
: "срочный"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: "Задача"

, "State"
: "Состояние"

, "Source"
: "Источник"

, "Scheduled end"
: "Запланированный конец"

, "Folder"
: "Папка"

, "Updated by"
: "Обновлено"

, "Updated Fields:"
: "Обновлённые поля:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Предложение %s было изменено"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Ведущим %s было создано"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Все предложения, которые я могу видеть"

, "Last modified by me"
: "Мои последнии изменения"

, "All leads that I have last modified"
: "Все последние изменённые мной предложения"

, "My leads"
: "Мои предложения"

, "All leads that I am responsible for"
: "Все предложения, за которые я ответственнен"

, "Leads with overdue tasks"
: "Предложения с просроченными задачами"

, "manage shared lead folders"
: "управлять общими папками предложений"

, "Create new shared lead folders"
: "Создать новую общую папку предложений"

, "manage shared leads favorites"
: "управление избранными общими предложениями"

, "Create or update shared leads favorites"
: "Создание или обновление избранных общих предложений"




, "Lead"
: "Предложения"

, "lead list"
: "Лист предложений"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
